**Example 1: 轮转云产品凭据**



Input: 

```
tccli ssm RotateProductSecret --cli-unfold-argument  \
    --SecretName test
```

Output: 
```
{
    "Response": {
        "RequestId": "2609a8fd-4584-4f89-98be-8c7ae1b81ef4",
        "FlowID": 0
    }
}
```

